@@ -139,6 +139,8 @@ private slots:
 private:
     bool getSystemProxies (QNetworkProxy &http, QNetworkProxy &https);
 
+    bool doGet(QUrl url, AsyncTaskToken *token, const char *ua,
+               QObject *receiver, const char *method);
     bool doGet(QUrl url, AsyncTaskToken *token, QObject *receiver,
                const char *method);
     bool doGet(const QString &strUrl, AsyncTaskToken *token, QObject *receiver,
@@ -154,6 +156,8 @@ private:
     bool doPostText(QUrl url, QByteArray postData, AsyncTaskToken *token,
                     QObject *receiver, const char *method);
 
+    void updateLoggedInFlag(AsyncTaskToken *task, const QString &strResponse);
+
     // Login and two factor
     bool postLogin(QUrl url, AsyncTaskToken *token);
     bool parseHiddenLoginFields(const QString &strResponse, QVariantMap &ret);
@@ -205,16 +209,16 @@ private:
 private:
     bool emitLog;
 
-    bool loggedIn;
-    QString rnr_se;
+    bool m_loggedIn;
+    QString m_rnr_se;
     //! The users Google Voice number
-    QString strSelfNumber;
+    QString m_strSelfNumber;
 
-    QNetworkAccessManager *nwMgr;
-    CookieJar *jar;
-    QVariantMap hiddenLoginFields;
+    QNetworkAccessManager *m_nwMgr;
+    CookieJar *m_jar;
+    QVariantMap m_hiddenLoginFields;
 
-    bool dbgAlwaysFailDialing;
+    bool m_dbgAlwaysFailDialing;
 };
 
 #endif // GVAPI_H
