@@ -70,8 +70,8 @@ extern "C" {
 #endif
 
 #define LIBMOSQUITTO_MAJOR 1
-#define LIBMOSQUITTO_MINOR 2
-#define LIBMOSQUITTO_REVISION 3
+#define LIBMOSQUITTO_MINOR 3
+#define LIBMOSQUITTO_REVISION 0
 /* LIBMOSQUITTO_VERSION_NUMBER looks like 1002001 for e.g. version 1.2.1. */
 #define LIBMOSQUITTO_VERSION_NUMBER (LIBMOSQUITTO_MAJOR*1000000+LIBMOSQUITTO_MINOR*1000+LIBMOSQUITTO_REVISION)
 
@@ -88,46 +88,47 @@ extern "C" {
 
 /* Error values */
 enum mosq_err_t {
-    MOSQ_ERR_CONN_PENDING = -1,
-    MOSQ_ERR_SUCCESS = 0,
-    MOSQ_ERR_NOMEM = 1,
-    MOSQ_ERR_PROTOCOL = 2,
-    MOSQ_ERR_INVAL = 3,
-    MOSQ_ERR_NO_CONN = 4,
-    MOSQ_ERR_CONN_REFUSED = 5,
-    MOSQ_ERR_NOT_FOUND = 6,
-    MOSQ_ERR_CONN_LOST = 7,
-    MOSQ_ERR_TLS = 8,
-    MOSQ_ERR_PAYLOAD_SIZE = 9,
-    MOSQ_ERR_NOT_SUPPORTED = 10,
-    MOSQ_ERR_AUTH = 11,
-    MOSQ_ERR_ACL_DENIED = 12,
-    MOSQ_ERR_UNKNOWN = 13,
-    MOSQ_ERR_ERRNO = 14,
-    MOSQ_ERR_EAI = 15
+	MOSQ_ERR_CONN_PENDING = -1,
+	MOSQ_ERR_SUCCESS = 0,
+	MOSQ_ERR_NOMEM = 1,
+	MOSQ_ERR_PROTOCOL = 2,
+	MOSQ_ERR_INVAL = 3,
+	MOSQ_ERR_NO_CONN = 4,
+	MOSQ_ERR_CONN_REFUSED = 5,
+	MOSQ_ERR_NOT_FOUND = 6,
+	MOSQ_ERR_CONN_LOST = 7,
+	MOSQ_ERR_TLS = 8,
+	MOSQ_ERR_PAYLOAD_SIZE = 9,
+	MOSQ_ERR_NOT_SUPPORTED = 10,
+	MOSQ_ERR_AUTH = 11,
+	MOSQ_ERR_ACL_DENIED = 12,
+	MOSQ_ERR_UNKNOWN = 13,
+	MOSQ_ERR_ERRNO = 14,
+	MOSQ_ERR_EAI = 15
 };
 
 /* MQTT specification restricts client ids to a maximum of 23 characters */
 #define MOSQ_MQTT_ID_MAX_LENGTH 23
 
 struct mosquitto_message{
-    int mid;
-    char *topic;
-    void *payload;
-    int payloadlen;
-    int qos;
-    bool retain;
+	int mid;
+	char *topic;
+	void *payload;
+	int payloadlen;
+	int qos;
+	bool retain;
 };
 
 struct mosquitto;
 
 /*
  * Topic: Threads
- *	libmosquitto provides thread safe operation.
+ *	libmosquitto provides thread safe operation, with the exception of
+ *	<mosquitto_lib_init> which is not thread safe.
  */
 /***************************************************
  * Important note
- *
+ * 
  * The following functions that deal with network operations will return
  * MOSQ_ERR_SUCCESS on success, but this does not mean that the operation has
  * taken place. An attempt will be made to write the network data, but if the
@@ -174,6 +175,8 @@ libmosq_EXPORT int mosquitto_lib_version(int *major, int *minor, int *revision);
  *
  * Must be called before any other mosquitto functions.
  *
+ * This function is *not* thread safe.
+ *
  * Returns:
  * 	MOSQ_ERR_SUCCESS - always
  *
@@ -226,7 +229,7 @@ libmosq_EXPORT int mosquitto_lib_cleanup(void);
  */
 libmosq_EXPORT struct mosquitto *mosquitto_new(const char *id, bool clean_session, void *obj);
 
-/*
+/* 
  * Function: mosquitto_destroy
  *
  * Use to free memory associated with a mosquitto client instance.
@@ -268,7 +271,7 @@ libmosq_EXPORT void mosquitto_destroy(struct mosquitto *mosq);
  */
 libmosq_EXPORT int mosquitto_reinitialise(struct mosquitto *mosq, const char *id, bool clean_session, void *obj);
 
-/*
+/* 
  * Function: mosquitto_will_set
  *
  * Configure will information for a mosquitto instance. By default, clients do
@@ -293,7 +296,7 @@ libmosq_EXPORT int mosquitto_reinitialise(struct mosquitto *mosq, const char *id
  */
 libmosq_EXPORT int mosquitto_will_set(struct mosquitto *mosq, const char *topic, int payloadlen, const void *payload, int qos, bool retain);
 
-/*
+/* 
  * Function: mosquitto_will_clear
  *
  * Remove a previously configured will. This must be called before calling
@@ -364,7 +367,7 @@ libmosq_EXPORT int mosquitto_connect(struct mosquitto *mosq, const char *host, i
  *
  * Connect to an MQTT broker. This extends the functionality of
  * <mosquitto_connect> by adding the bind_address parameter. Use this function
- * if you need to restrict network communication over a particular interface.
+ * if you need to restrict network communication over a particular interface. 
  *
  * Parameters:
  * 	mosq -         a valid mosquitto instance.
@@ -430,7 +433,7 @@ libmosq_EXPORT int mosquitto_connect_async(struct mosquitto *mosq, const char *h
  *
  * This extends the functionality of <mosquitto_connect_async> by adding the
  * bind_address parameter. Use this function if you need to restrict network
- * communication over a particular interface.
+ * communication over a particular interface. 
  *
  * May be called before or after <mosquitto_loop_start>.
  *
@@ -457,6 +460,42 @@ libmosq_EXPORT int mosquitto_connect_async(struct mosquitto *mosq, const char *h
  */
 libmosq_EXPORT int mosquitto_connect_bind_async(struct mosquitto *mosq, const char *host, int port, int keepalive, const char *bind_address);
 
+/*
+ * Function: mosquitto_connect_srv
+ *
+ * Connect to an MQTT broker. This is a non-blocking call. If you use
+ * <mosquitto_connect_async> your client must use the threaded interface
+ * <mosquitto_loop_start>. If you need to use <mosquitto_loop>, you must use
+ * <mosquitto_connect> to connect the client.
+ *
+ * This extends the functionality of <mosquitto_connect_async> by adding the
+ * bind_address parameter. Use this function if you need to restrict network
+ * communication over a particular interface. 
+ *
+ * May be called before or after <mosquitto_loop_start>.
+ *
+ * Parameters:
+ * 	mosq -         a valid mosquitto instance.
+ * 	host -         the hostname or ip address of the broker to connect to.
+ * 	keepalive -    the number of seconds after which the broker should send a PING
+ *                 message to the client if no other messages have been exchanged
+ *                 in that time.
+ *  bind_address - the hostname or ip address of the local network interface to
+ *                 bind to.
+ *
+ * Returns:
+ * 	MOSQ_ERR_SUCCESS - on success.
+ * 	MOSQ_ERR_INVAL -   if the input parameters were invalid.
+ * 	MOSQ_ERR_ERRNO -   if a system call returned an error. The variable errno
+ *                     contains the error code, even on Windows.
+ *                     Use strerror_r() where available or FormatMessage() on
+ *                     Windows.
+ *
+ * See Also:
+ * 	<mosquitto_connect_async>, <mosquitto_connect>, <mosquitto_connect_bind>
+ */
+libmosq_EXPORT int mosquitto_connect_srv(struct mosquitto *mosq, const char *host, int keepalive, const char *bind_address);
+
 /*
  * Function: mosquitto_reconnect
  *
@@ -466,7 +505,7 @@ libmosq_EXPORT int mosquitto_connect_bind_async(struct mosquitto *mosq, const ch
  * connection has been lost. It uses the values that were provided in the
  * <mosquitto_connect> call. It must not be called before
  * <mosquitto_connect>.
- *
+ * 
  * Parameters:
  * 	mosq - a valid mosquitto instance.
  *
@@ -497,7 +536,7 @@ libmosq_EXPORT int mosquitto_reconnect(struct mosquitto *mosq);
  * connection has been lost. It uses the values that were provided in the
  * <mosquitto_connect> or <mosquitto_connect_async> calls. It must not be
  * called before <mosquitto_connect>.
- *
+ * 
  * Parameters:
  * 	mosq - a valid mosquitto instance.
  *
@@ -534,11 +573,11 @@ libmosq_EXPORT int mosquitto_reconnect_async(struct mosquitto *mosq);
  */
 libmosq_EXPORT int mosquitto_disconnect(struct mosquitto *mosq);
 
-/*
+/* 
  * Function: mosquitto_publish
  *
  * Publish a message on a given topic.
- *
+ * 
  * Parameters:
  * 	mosq -       a valid mosquitto instance.
  * 	mid -        pointer to an int. If not NULL, the function will set this
@@ -565,7 +604,7 @@ libmosq_EXPORT int mosquitto_disconnect(struct mosquitto *mosq);
  *                          broker.
  * 	MOSQ_ERR_PAYLOAD_SIZE - if payloadlen is too large.
  *
- * See Also:
+ * See Also: 
  *	<mosquitto_max_inflight_messages_set>
  */
 libmosq_EXPORT int mosquitto_publish(struct mosquitto *mosq, int *mid, const char *topic, int payloadlen, const void *payload, int qos, bool retain);
@@ -635,7 +674,7 @@ libmosq_EXPORT int mosquitto_message_copy(struct mosquitto_message *dst, const s
 
 /*
  * Function: mosquitto_message_free
- *
+ * 
  * Completely free a mosquitto_message struct.
  *
  * Parameters:
@@ -666,7 +705,7 @@ libmosq_EXPORT void mosquitto_message_free(struct mosquitto_message **message);
  * <mosquitto_loop_misc>.
  *
  * Threads:
- *
+ *	
  * Parameters:
  *	mosq -        a valid mosquitto instance.
  *	timeout -     Maximum number of milliseconds to wait for network activity
@@ -674,7 +713,7 @@ libmosq_EXPORT void mosquitto_message_free(struct mosquitto_message **message);
  *	              return.  Set negative to use the default of 1000ms.
  *	max_packets - this parameter is currently unused and should be set to 1 for
  *	              future compatibility.
- *
+ * 
  * Returns:
  *	MOSQ_ERR_SUCCESS -   on success.
  * 	MOSQ_ERR_INVAL -     if the input parameters were invalid.
@@ -929,9 +968,9 @@ libmosq_EXPORT bool mosquitto_want_write(struct mosquitto *mosq);
  *	<mosquitto_tls_opts_set>, <mosquitto_tls_psk_set>, <mosquitto_tls_insecure_set>
  */
 libmosq_EXPORT int mosquitto_tls_set(struct mosquitto *mosq,
-        const char *cafile, const char *capath,
-        const char *certfile, const char *keyfile,
-        int (*pw_callback)(char *buf, int size, int rwflag, void *userdata));
+		const char *cafile, const char *capath,
+		const char *certfile, const char *keyfile,
+		int (*pw_callback)(char *buf, int size, int rwflag, void *userdata));
 
 /*
  * Function: mosquitto_tls_insecure_set
@@ -1021,7 +1060,7 @@ libmosq_EXPORT int mosquitto_tls_opts_set(struct mosquitto *mosq, int cert_reqs,
  */
 libmosq_EXPORT int mosquitto_tls_psk_set(struct mosquitto *mosq, const char *psk, const char *identity, const char *ciphers);
 
-/*
+/* 
  * Function: mosquitto_connect_callback_set
  *
  * Set the connect callback. This is called when the broker sends a CONNACK
@@ -1044,13 +1083,13 @@ libmosq_EXPORT int mosquitto_tls_psk_set(struct mosquitto *mosq, const char *psk
  * * 4-255 - reserved for future use
  */
 libmosq_EXPORT void mosquitto_connect_callback_set(struct mosquitto *mosq, void (*on_connect)(struct mosquitto *, void *, int));
-
+ 
 /*
  * Function: mosquitto_disconnect_callback_set
  *
  * Set the disconnect callback. This is called when the broker has received the
  * DISCONNECT command and has disconnected the client.
- *
+ * 
  * Parameters:
  *  mosq -          a valid mosquitto instance.
  *  on_disconnect - a callback function in the following form:
@@ -1064,13 +1103,13 @@ libmosq_EXPORT void mosquitto_connect_callback_set(struct mosquitto *mosq, void
  *         indicates that the disconnect is unexpected.
  */
 libmosq_EXPORT void mosquitto_disconnect_callback_set(struct mosquitto *mosq, void (*on_disconnect)(struct mosquitto *, void *, int));
-
+ 
 /*
  * Function: mosquitto_publish_callback_set
  *
  * Set the publish callback. This is called when a message initiated with
  * <mosquitto_publish> has been sent to the broker successfully.
- *
+ * 
  * Parameters:
  *  mosq -       a valid mosquitto instance.
  *  on_publish - a callback function in the following form:
@@ -1088,7 +1127,7 @@ libmosq_EXPORT void mosquitto_publish_callback_set(struct mosquitto *mosq, void
  *
  * Set the message callback. This is called when a message is received from the
  * broker.
- *
+ * 
  * Parameters:
  *  mosq -       a valid mosquitto instance.
  *  on_message - a callback function in the following form:
@@ -1111,7 +1150,7 @@ libmosq_EXPORT void mosquitto_message_callback_set(struct mosquitto *mosq, void
  *
  * Set the subscribe callback. This is called when the broker responds to a
  * subscription request.
- *
+ * 
  * Parameters:
  *  mosq -         a valid mosquitto instance.
  *  on_subscribe - a callback function in the following form:
@@ -1132,7 +1171,7 @@ libmosq_EXPORT void mosquitto_subscribe_callback_set(struct mosquitto *mosq, voi
  *
  * Set the unsubscribe callback. This is called when the broker responds to a
  * unsubscription request.
- *
+ * 
  * Parameters:
  *  mosq -           a valid mosquitto instance.
  *  on_unsubscribe - a callback function in the following form:
@@ -1235,7 +1274,7 @@ libmosq_EXPORT int mosquitto_max_inflight_messages_set(struct mosquitto *mosq, u
  *
  * Set the number of seconds to wait before retrying messages. This applies to
  * publish messages with QoS>0. May be called at any time.
- *
+ * 
  * Parameters:
  *  mosq -          a valid mosquitto instance.
  *  message_retry - the number of seconds to wait for a response before
@@ -1262,13 +1301,13 @@ libmosq_EXPORT void mosquitto_user_data_set(struct mosquitto *mosq, void *obj);
 
 /* =============================================================================
  *
- * Utility functions
+ * Section: Utility functions
  *
  * =============================================================================
  */
 
 /*
- * Function mosquitto_strerror
+ * Function: mosquitto_strerror
  *
  * Call to obtain a const string description of a mosquitto error number.
  *
@@ -1281,7 +1320,7 @@ libmosq_EXPORT void mosquitto_user_data_set(struct mosquitto *mosq, void *obj);
 libmosq_EXPORT const char *mosquitto_strerror(int mosq_errno);
 
 /*
- * Function mosquitto_connack_string
+ * Function: mosquitto_connack_string
  *
  * Call to obtain a const string description of an MQTT connection result.
  *
@@ -1294,7 +1333,7 @@ libmosq_EXPORT const char *mosquitto_strerror(int mosq_errno);
 libmosq_EXPORT const char *mosquitto_connack_string(int connack_code);
 
 /*
- * Function mosquitto_sub_topic_tokenise
+ * Function: mosquitto_sub_topic_tokenise
  *
  * Tokenise a topic or subscription string into an array of strings
  * representing the topic hierarchy.
@@ -1336,7 +1375,7 @@ libmosq_EXPORT const char *mosquitto_connack_string(int connack_code);
  * > char **topics;
  * > int topic_count;
  * > int i;
- * >
+ * > 
  * > mosquitto_sub_topic_tokenise("$SYS/broker/uptime", &topics, &topic_count);
  * >
  * > for(i=0; i<token_count; i++){
@@ -1349,7 +1388,7 @@ libmosq_EXPORT const char *mosquitto_connack_string(int connack_code);
 libmosq_EXPORT int mosquitto_sub_topic_tokenise(const char *subtopic, char ***topics, int *count);
 
 /*
- * Function mosquitto_sub_topic_tokens_free
+ * Function: mosquitto_sub_topic_tokens_free
  *
  * Free memory that was allocated in <mosquitto_sub_topic_tokenise>.
  *
@@ -1367,7 +1406,7 @@ libmosq_EXPORT int mosquitto_sub_topic_tokenise(const char *subtopic, char ***to
 libmosq_EXPORT int mosquitto_sub_topic_tokens_free(char ***topics, int count);
 
 /*
- * Function mosquitto_topic_matches_sub
+ * Function: mosquitto_topic_matches_sub
  *
  * Check whether a topic matches a subscription.
  *
