@@ -23,7 +23,7 @@ Contact: yuvraaj@gmail.com
 #define _CQMLVIEWER_
 
 #include "global.h"
-#include <QtQuick>
+#include <QtQuick/QtQuick>
 
 class QmlApplicationViewer {
 public:
@@ -40,7 +40,7 @@ public:
     CQmlViewer();
 
     inline void setMainQmlFile(const QString &qmlFile) {
-        m_view->setSource(QUrl::fromLocalFile(qmlFile));
+        m_view->setSource(QUrl(qmlFile));
     }
 
     // Stupid hack to shut up the warnings
