@@ -33,11 +33,6 @@ class MainWindowPrivate;
 class QSystemTrayIcon;
 class QWebView;
 
-struct LogMessage {
-    QString message;
-    quint64 milli;
-};
-
 class MainWindow : public IMainWindow
 {
     Q_OBJECT
@@ -121,8 +116,6 @@ protected slots:
     void onSbContactsFreqChanged(int val);
     void onSbInboxFreqChanged(int val);
 
-    void onLogMessagesTimer();
-
 private:
     MainWindowPrivate *d;
 
@@ -133,10 +126,6 @@ private:
 
     bool m_ignoreCbInboxChange;
 
-    QMutex      m_logMessageMutex;
-    QVector <LogMessage> m_logMessages;
-    QTimer      m_logMessageTimer;
-
 #ifdef DBUS_API
 protected slots:
     bool initDBus();
